.. _sample-configuration:

-------
Samples
-------

The following sections show sample configuration files for monasca-api and
related utilities. These are generated from the code
(apart from the samples for logging and paster) and reflect the current state
of code in the monasca-api repository.


.. _sample-configuration-api:

Sample Configuration For Application
------------------------------------

This sample configuration can also be viewed in `monasca-api.conf.sample
<../_static/monasca-api.conf.sample>`_.

.. literalinclude:: ../_static/monasca-api.conf.sample

.. _sample-configuration-logging:

Sample Configuration For Logging
--------------------------------

This sample configuration can also be viewed in `api-logging.conf
<https://git.openstack.org/cgit/openstack/monasca-api/plain/etc/api-logging.conf>`_.

.. literalinclude:: ../../../etc/api-logging.conf


Sample Configuration For Paster
-------------------------------

This sample configuration can also be viewed in `api-config.ini
<https://git.openstack.org/cgit/openstack/monasca-api/plain/etc/api-config.ini>`_.

.. literalinclude:: ../../../etc/api-config.ini
